@@ -75,8 +75,8 @@ my %warned;
 sub preferred_downloader {
     my ($urpm, $medium, $use_metalink) = @_;
 
-    my @available = urpm::download::available_ftp_http_downloaders();
-    my @metalink_downloaders = urpm::download::available_metalink_downloaders();
+    my @available = available_ftp_http_downloaders();
+    my @metalink_downloaders = available_metalink_downloaders();
     my $metalink_disabled = !$$use_metalink && $medium->{disable_metalink};
 
     if ($$use_metalink && !$metalink_disabled) {
@@ -197,7 +197,7 @@ sub get_proxy (;$) {
 	our $PROMPT_PROXY;
 	unless (defined $PROMPT_PROXY) {
 	    require urpm::prompt;
-	    $PROMPT_PROXY = new urpm::prompt(
+	    $PROMPT_PROXY = urpm::prompt->new(
 		N("Please enter your credentials for accessing proxy\n"),
 		[ N("User name:"), N("Password:") ],
 		undef,
@@ -488,8 +488,8 @@ sub sync_curl {
     #- options for http files, -R (-O <file>)*
     my $result;
     if (my @all_files = (
-	    (map { ("-O", $_) } @ftp_files),
-	    (map { m|/| ? ("-O", $_) : @{[]} } @other_files)))
+	    (map { (_curl_output_option($_), $_) } @ftp_files),
+	    (map { m|/| ? (_curl_output_option($_), $_) : @{[]} } @other_files)))
     {
 	my @l = (@ftp_files, @other_files);
 	my $cmd = join(" ", map { "'$_'" } "/usr/bin/curl",
@@ -516,6 +516,15 @@ sub sync_curl {
     $result;
 }
 
+sub _curl_output_option {
+    my ($remote_file) = @_;
+    #- curl 7.86 changed the -O option to remove any trailing query part from the output
+    #- file name. So if we have a query part, use the -o option instead. If not, use the
+    #- -O option to avoid bloating the command line.
+    my $local_file = basename($remote_file);
+    $local_file =~ /\?/ ? ('-o', $local_file) : '-O';
+}
+
 sub _curl_action {
     my ($cmd, $options, @l) = @_;
     
@@ -1032,7 +1041,7 @@ sub _sync_webfetch_raw {
 	if ($preferred eq 'aria2') {
 	    sync_aria2($urpm, $medium, $rel_files, $options);
 	} else {
-	  my $sync = $urpm::download::{"sync_$preferred"} or die N("no webfetch found, supported webfetch are: %s\n", join(", ", urpm::download::ftp_http_downloaders()));
+	  my $sync = $urpm::download::{"sync_$preferred"} or die N("no webfetch found, supported webfetch are: %s\n", join(", ", ftp_http_downloaders()));
 
 	  my @l = @$files;
 	  while (@l) {
