@@ -1,27 +1,26 @@
 package urpm::parallel_ka_run;
 
-# $Id: parallel_ka_run.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 #- Copyright (C) 2002, 2003, 2004, 2005 MandrakeSoft SA
 #- Copyright (C) 2005-2010 Mandriva SA
+#- Copyright (C) 2011-2020 Mageia
 
 use strict;
-use urpm::util;
+use urpm::util 'find';
 use urpm::msg;
 use urpm::parallel;
 
 our @ISA = 'urpm::parallel';
 
-(our $VERSION) = q($Revision: 271299 $) =~ /(\d+)/;
 our $mput_command = $ENV{URPMI_MPUT_COMMAND};
 our $rshp_command = $ENV{URPMI_RSHP_COMMAND};
 
 if (!$mput_command) {
-    ($mput_command) = grep { -x $_ } qw(/usr/bin/mput2 /usr/bin/mput);
+    ($mput_command) = find { -x $_ } qw(/usr/bin/mput2 /usr/bin/mput);
 }
 $mput_command ||= 'mput';
 if (!$rshp_command) {
-    ($rshp_command) = grep { -x $_ } qw(/usr/bin/rshp2 /usr/bin/rshp);
+    ($rshp_command) = find { -x $_ } qw(/usr/bin/rshp2 /usr/bin/rshp);
 }
 $rshp_command ||= 'rshp';
 
